# Py-Packager

A simple lightweight tool to generate standard python package structure for you.

# Install

Install from pypi with -

```
pip install py-packager
```


# Usage

Very simple just go into package source folder and run 

```
py-packager
```

and continue with the questions. At the end it will generate a standard package structure for you.


